test_that('simpson copied', {
  expect_identical(ds_simpson, ds_hhi)
})
